@@ -4,12 +4,12 @@ use strict;
 use warnings FATAL => 'all';
 use Module::Runtime qw[ require_module ];
 
-our $VERSION = "0.04_01";
+our $VERSION = "0.01";
 $VERSION = eval $VERSION;
 
 #For instances when you want to use s3, but don't want to install anything. ( and you have curl )
 #Amazon S3 Authentication Tool for Curl
-#Copyright 2006-2010 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+#Copyright 2006-2010 Amazon.com, Inc. or its affiliates. All Rights Reserved. 
 use Moo;
 use POSIX;
 use File::Spec;
@@ -18,7 +18,7 @@ use Log::Contextual::SimpleLogger;
 use Digest::SHA::PurePerl;
 use MIME::Base64 qw(encode_base64);
 use IPC::System::Simple qw[ capture ];
-my $DIGEST_HMAC;
+our $DIGEST_HMAC;
 BEGIN {
     eval {
         require_module("Digest::HMAC");
@@ -40,13 +40,14 @@ set_logger(
 
 has curl => (
     is      => 'ro',
-    default => sub { 'curl' }    #maybe your curl isnt in PATH?
+    default => sub { 'curl' }    #maybe your curl isnt in path?
 );
 
 for (
     qw[
     aws_access_key
     aws_secret_key
+    url
     ] )
 {
     has $_ => (
@@ -56,17 +57,9 @@ for (
 
 }
 
-has url => (
+has local_file => ( 
     is => 'ro',
     required => 1,
-    isa => sub {
-        $_[0] =~ m|^/| or die "$_[0] is not a relative url. Should be /bucketname/file"
-      },
-);
-
-has local_file => (
-    is => 'ro',
-    required => 0,
     predicate => 1,
 );
 
@@ -75,17 +68,12 @@ has static_http_date => (
     required => 0,
 );
 
-has s3_scheme_host_url => (
-    is => 'ro',
-    lazy => 1,
-    default => sub {
-        my $env_var = $ENV{AMAZON_S3CURL_PUREPERL_SCHEME_HOST};
-        return $env_var if defined $env_var;
-        return 'http://s3.amazonaws.com'
-    }
+has http_date => (
+    is => 'lazy',
+    clearer => 1,
 );
 
-sub http_date {
+sub _build_http_date {
     POSIX::strftime( "%a, %d %b %Y %H:%M:%S +0000", gmtime );
 }
 
@@ -93,9 +81,11 @@ sub _req {
     my ( $self, $method, $url ) = @_;
     die "method required" unless $method;
     $url ||= $self->url;
+    my $resource = $url;
     my $to_sign  = $url;
-    my $resource = sprintf( "%s%s" , $self->s3_scheme_host_url, $url );
+    $resource = "http://s3.amazonaws.com" . $resource;
     my $keyId       = $self->aws_access_key;
+    $self->clear_http_date;
     my $httpDate    = $self->static_http_date || $self->http_date;
     my $contentMD5  = "";
     my $contentType = "";
@@ -143,27 +133,10 @@ sub upload_cmd {
 
 sub delete_cmd {
     my $args = shift->_req('DELETE');
-    splice( @$args, $#$args, 0, qw[ -X DELETE ] );
+    splice( @$args, $#$args, 0, -X  => 'DELETE' );
     return $args;
 }
 
-sub head_cmd {
-    my $args = shift->_req('HEAD');
-    splice( @$args, $#$args, 0, qw[ -I -X HEAD ] );
-    return $args;
-}
-
-sub url_exists {
-    my $self = shift;
-    my @args = grep { !/-f/ } @{ $self->head_cmd }; #take out fail mode, want to parse and look for the 404.
-    log_info { "running " . join( " ", @_ ) } @args;
-    my @output = capture( @args );
-    die "no output received!" unless @output;
-    return 1 if $output[0] =~ /200 OK/;
-    return 0 if $output[0] =~ /404 Not Found/;
-    die "url_exists did not find a 200 or 404: $output[0]";
-}
-
 sub _exec {
     my($self,$method) = @_;
     my $meth = $method."_cmd";
@@ -186,10 +159,6 @@ sub delete {
     return shift->_exec("delete");
 }
 
-sub head {
-    return shift->_exec("head");
-}
-
 sub _local_file_required {
     my $method = shift;
     sub {
@@ -209,11 +178,11 @@ Amazon::S3Curl::PurePerl - Pure Perl s3 helper/downloader.
 
 =head1 VERSION
 
-version 0.04_01
+version 0.01
 
 =head1 DESCRIPTION
 
-This software is designed to run in low dependency situations.
+This software is designed to run in low dependency situations. 
 You need curl, and you need perl ( If you are on linux, you probably have perl whether you know it or not ).
 
 Maybe you're bootstrapping a system from s3,
@@ -228,9 +197,9 @@ or downloading software to a host where you can't/don't want to install anything
             url            => "/mybootstrap-files/myapp.tgz"
     });
     $s3curl->download;
-
+    
 Using L<Object::Remote>:
-
+    
     use Object::Remote;
     my $conn = Object::Remote->connect("webserver-3");
 
@@ -278,19 +247,19 @@ Constructor, provided by Moo.
 =head2 download
 
     $s3curl->download;
-
+    
 download url to local_file.
 
 =head2 upload
 
     $s3curl->upload;
-
+    
 Upload local_file to url.
 
 =head2 delete
 
     $s3curl->delete;
-
+    
 Delete url.
 
 =head2 delete_cmd
@@ -299,14 +268,9 @@ Delete url.
 
 =head2 upload_cmd
 
-Just get the command to execute in the form of an arrayref, don't actually execute it:
-
+Just get the command to execute, don't actually execute it:
     my $cmd = $s3curl->download_cmd;
-    system(@$cmd);
-
-=head2 url_exists
-
-Check to see if a given url returns a 404 or 200. return 1 if 200, return 0 if 404, die otherwise.
+    `$cmd`;
 
 =head1 LICENSE
 
@@ -314,7 +278,7 @@ This library is free software and may be distributed under the same terms as per
 
 =head1 AUTHOR AND CONTRIBUTORS
 
-This distribution was
+This distribution was 
 adapted by Samuel Kaufman L<skaufman@cpan.org> from the L<Amazon S3 Authentication Tool for Curl|http://aws.amazon.com/code/128>
 
    Amazon S3 Authentication Tool for Curl
